@@ -428,7 +428,7 @@ usage() {
 		"  -N <nodata> NODATA value to use on bands without a NODATA value.\n"
 	));
 	printf(_(
-		"  -k  Skip NODATA value checks for each raster band.\n"
+		"  -k  Keep empty tiles by skipping NODATA value checks for each raster band. \n"
 	));
 	printf(_(
 		"  -E <endian> Control endianness of generated binary output of\n"
@@ -443,8 +443,10 @@ usage() {
 		"  -e  Execute each statement individually, do not use a transaction.\n"
 	));
 	printf(_(
-		"  -Y  Use COPY statements instead of INSERT statements.\n"
+		"  -Y <max_rows_per_copy> Use COPY statements instead of INSERT statements. \n"
+		"    Optionally specify <max_rows_per_copy>; default 50 when not specified. \n"
 	));
+
 	printf(_(
 		"  -G  Print the supported GDAL raster formats.\n"
 	));
@@ -700,6 +702,7 @@ init_config(RTLOADERCFG *config) {
 	config->version = 0;
 	config->transaction = 1;
 	config->copy_statements = 0;
+	config->max_tiles_per_copy = 50;
 }
 
 static void
@@ -1515,7 +1518,7 @@ build_overview(int idx, RTLOADERCFG *config, RASTERINFO *info, uint32_t ovx, STR
 			GDALClose(hdsDst);
 
 			/* flush if tileset gets too big */
-			if (tileset->length > 10) {
+			if (tileset->length >= config->max_tiles_per_copy) {
 				if (!insert_records(
 					config->schema, ovtable, config->raster_column,
 					(config->file_column ? config->rt_filename[idx] : NULL), config->file_column_name,
@@ -1842,7 +1845,7 @@ convert_raster(int idx, RTLOADERCFG *config, RASTERINFO *info, STRINGBUFFER *til
 					append_stringbuffer(tileset, hex);
 
 				/* flush if tileset gets too big */
-				if (tileset->length > 10) {
+				if (tileset->length >= config->max_tiles_per_copy ) {
 					if (!insert_records(
 						config->schema, config->table, config->raster_column,
 						(config->file_column ? config->rt_filename[idx] : NULL), config->file_column_name,
@@ -1965,7 +1968,7 @@ convert_raster(int idx, RTLOADERCFG *config, RASTERINFO *info, STRINGBUFFER *til
 				GDALClose(hdsDst);
 
 				/* flush if tileset gets too big */
-				if (tileset->length > 10) {
+				if (tileset->length >= config->max_tiles_per_copy ) {
 					if (!insert_records(
 						config->schema, config->table, config->raster_column,
 						(config->file_column ? config->rt_filename[idx] : NULL), config->file_column_name,
@@ -2595,7 +2598,17 @@ main(int argc, char **argv) {
 		/* COPY statements */
 		else if (CSEQUAL(argv[argit], "-Y")) {
 			config->copy_statements = 1;
+			/* max tiles per copy */
+			if ( argit < argc - 1) {
+				optarg = argv[argit + 1];
+				if (atoi(optarg) > 0 ) {
+					config->max_tiles_per_copy = atoi(optarg);
+					++argit;
+				}
+			}
 		}
+
+
 		/* GDAL formats */
 		else if (CSEQUAL(argv[argit], "-G")) {
 			uint32_t drv_count = 0;
